@@ -1,5 +1,5 @@
 #
-# $Id: Perl6.pm 26689 2009-05-06 07:17:19Z azawawi $
+# $Id: Perl6.pm 26710 2009-05-07 08:50:06Z azawawi $
 #
 package Syntax::Highlight::Perl6;
 
@@ -7,23 +7,16 @@ package Syntax::Highlight::Perl6;
 use 5.010;
 use strict;
 use warnings;
-use English '-no_match_vars';  # Avoids regex performance penalty
 use Carp;
-use Encode;
-use File::Basename qw(dirname);
-use File::Spec;
-use Cwd qw(realpath);
+
 require Exporter;
 
 # cpan modules
 use Term::ANSIColor;
 
-# Larry's STD.pm
-use STD;
-
 # exports and version
 our @EXPORT_OK = qw();
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 # filename constants
 my $FILE_CSS    = 'p6_style.css';
@@ -40,15 +33,20 @@ my @loc;
 if(! -f __FILE__) {
     croak 'Syntax::Highlight::Perl6 cannot see where it is installed'
 }
-my $SHARED = realpath(File::Spec->join(
-            dirname(__FILE__),'Perl6'));
+
+require File::Basename;
+require File::Spec;
+require Cwd;
+
+my $SHARED = Cwd::realpath(File::Spec->join(
+            File::Basename::dirname(__FILE__),'Perl6'));
 
 #----------------------------------------------------------------
 # Returns the syntax highlighting object. It needs a hash
 # of options.
 #----------------------------------------------------------------
 sub new {
-    my ($class, %options) = @ARG;
+    my ($class, %options) = @_;
     $options{rule} = $options{rule} // 'comp_unit';
     $options{inline_resources} = $options{inline_resources} // 0;
     $options{resource_url} = $options{resource_url} // q{};
@@ -78,8 +76,9 @@ sub _lazy_parse {
     if(!$self->{parsed_lazily}) {
 
         # utf8-decode if required
+        require Encode;
         my $src_text = $self->{utf8_decode} ?
-            decode('utf8', $self->{text} ) :
+            Encode::decode('utf8', $self->{text} ) :
             $self->{text};
 
         #grow the loc array while checking for empty strings
@@ -91,6 +90,7 @@ sub _lazy_parse {
         $loc[$len - 1] = [];
 
         #STD parse the text for the rule provided
+        require STD;
         $self->{parser} = STD->parse(
             $src_text, 
             rule => $self->{rule},
@@ -123,7 +123,7 @@ sub snippet_html {
     $str .= '<pre>';
 
     local *spit_snippet_html = sub {
-        my ($i, $buffer, $rule, $tree, $lineno) = @ARG;
+        my ($i, $buffer, $rule, $tree, $lineno) = @_;
         $buffer = _escape_html($buffer);
         my $style = $colors{$rule};
         if($rule) {
@@ -154,7 +154,7 @@ sub simple_html {
     my $css;
     if($self->{inline_resources}) {
         $css = _slurp(_shared($FILE_CSS))
-            or croak "Error while slurping file: $OS_ERROR\n";
+            or croak "Error while slurping file: $!\n";
         $css = qq{<style type="text/css">\n$css\n</style>};
     } else {
         my $prefix = $self->{resource_url};
@@ -167,7 +167,7 @@ sub simple_html {
 <head>
     <title>$page_title</title>
 <!--
-     Generated by $PROGRAM_NAME at $timestamp
+     Generated by $0 at $timestamp
 -->
     $css
 </head>
@@ -176,7 +176,7 @@ sub simple_html {
 HTML
 
     local *spit_simple_html = sub {
-        my ($i, $buffer, $rule, $tree, $lineno) = @ARG;
+        my ($i, $buffer, $rule, $tree, $lineno) = @_;
         $buffer = _escape_html($buffer);
         if($rule) {
             $str .= qq{<span class="$rule">$buffer</span>};
@@ -212,13 +212,13 @@ sub full_html {
     if($self->{inline_resources}) {
         my $contents;
         $contents = _slurp(_shared($FILE_JQUERY))
-            or croak "Error while slurping file: $OS_ERROR\n";
+            or croak "Error while slurping file: $!\n";
         $jquery_js = qq{<script type="text/javascript">\n$contents\n</script>};
         $contents = _slurp(_shared($FILE_JS))
-            or croak "Error while slurping file: $OS_ERROR\n";
+            or croak "Error while slurping file: $!\n";
         $js = qq{<script type="text/javascript">\n$contents\n</script>};
         $contents = _slurp(_shared($FILE_CSS))
-            or croak "Error while slurping file: $OS_ERROR\n";
+            or croak "Error while slurping file: $!\n";
         $css = qq{<style type="text/css">\n$contents\n</style>};
     } else {
         my $prefix = $self->{resource_url};
@@ -235,7 +235,7 @@ sub full_html {
 <head>
     <title>$page_title</title>
 <!--
-    Generated by $PROGRAM_NAME at $timestamp
+    Generated by $0 at $timestamp
 -->
     $css
     $jquery_js
@@ -252,7 +252,7 @@ sub full_html {
 HTML
 
     local *spit_full_html = sub {
-        my ($i, $buffer, $rule, $tree, $lineno) = @ARG;
+        my ($i, $buffer, $rule, $tree, $lineno) = @_;
         $buffer = _escape_html($buffer);
         $str .= qq{<span id="tree_$i" style="display:none;">$tree</span>};
         if($rule) {
@@ -284,11 +284,12 @@ sub ansi_text {
 
     my %colors = _read_ansi_file();
 
+    require Term::ANSIColor;
     local *spit_ansi_text = sub {
-        my ($i, $buffer, $rule, $tree, $lineno) = @ARG;
+        my ($i, $buffer, $rule, $tree, $lineno) = @_;
         if($rule) {
             my $color = $colors{$rule};
-            $str .= (color $color) . $buffer. (color 'reset');
+            $str .= (Term::ANSIColor::color $color) . $buffer. (Term::ANSIColor::color 'reset');
         } else {
             $str .= $buffer;
         }
@@ -313,11 +314,11 @@ sub tokens {
     my @tokens = ();
     local *spit_parse_tree = sub {
         push @tokens, {
-            'last_pos'  => $ARG[0],
-            'buffer'    => $ARG[1],
-            'rule'      => $ARG[2],
-            'tree'      => $ARG[3],
-            'lineno'    => $ARG[4],
+            'last_pos'  => $_[0],
+            'buffer'    => $_[1],
+            'rule'      => $_[2],
+            'tree'      => $_[3],
+            'lineno'    => $_[4],
         };
     };
     $self->_redspans_traverse(\&spit_parse_tree,%colors);
@@ -357,7 +358,7 @@ sub _read_css_file {
     my %colors = ();
     my $filename = _shared($FILE_CSS);
     my $fh = IO::File->new($filename)
-        or croak "Could not open $filename: $OS_ERROR\n";
+        or croak "Could not open $filename: $!\n";
     my $line;
     while($line = <$fh>) {
         if($line =~ /^\s*           # <whitespace>
@@ -382,7 +383,7 @@ sub _read_ansi_file {
     my %colors = ();
     my $filename = _shared($FILE_ANSI);
     my $fh = IO::File->new($filename)
-        or croak "Could not open $filename: $OS_ERROR\n";
+        or croak "Could not open $filename: $!\n";
     my $line;
     while($line = <$fh>) {
         if($line =~ m{^(\w+)     # <start> <rule-name>
@@ -405,7 +406,7 @@ sub _read_ansi_file {
 # colors hash.
 #---------------------------------------------------------------
 sub _redspans_traverse {
-    my ($self,$process_buffer,%colors) = @ARG;
+    my ($self,$process_buffer,%colors) = @_;
     my @loc = @{$self->{loc}};
     my ($last_tree,$buffer, $last_type) = (q{},q{},q{});
     my $parser = $self->{parser};
@@ -536,7 +537,7 @@ sub _slurp {
     my $filename = shift;
     my $fh = IO::File->new($filename)
         or croak "Could not open $filename for reading";
-    local $INPUT_RECORD_SEPARATOR = undef;   #enable localized slurp mode
+    local $/ = undef;   #enable localized slurp mode
     my $contents = <$fh>;
     close $fh
         or croak "Could not close $filename";
